#!/bin/bash 
#
#  $Id: doc_compile.sh,v 1.1 2002/02/22 17:19:42 philippe Exp $ 
#
# NAAT
#
# This is the XSL NAAT compilation script. 
# The first argument is the XML file to compile (.naat),
# the second is the stylesheet to apply (.xsl),
# the third a destination directory.
# the result is a set of html files, a file foreach page,
# generated by applying the stylesheet to the source.
# The logic is the following:
# 1) It applies the script_maker.xsl stylesheet to the .naat. 
#    The result is a bash script ("tmp.sh") that contains
#	 invocations of the .xsl to the .naat, in turn, for every page in the .naat
# 2) It calls the resulting script.
# In order to work properly, the first argument of this script
# must be named <file>.naat, and the associated wvm file must be
# named <file>.wvm

# choice of the version of XSL generator to use (C, C++ or java)
XSL_COMPILER=xsltproc
XSL_COMPILER_OPTIONS=--timing
#XSL_COMPILER=xsl-c
#XSL_COMPILER=java org.apache.xalan.xslt.Process 

DIRNAME=$(basename `dirname $1`)
BASENAME=`basename $1 .naat`
TEMP="tmp/$DIRNAME"

# Functions

# return the status of the last command
exit_value() {
	EXIT=$?
	if [ $EXIT -gt 0 ]; then
		return $EXIT;
	fi
}

# End functions

# create tmp DIR
[ -d $TEMP ] || mkdir $TEMP

# compile module
if [ "${XSL_COMPILER}" = "xsltproc" ]; then
    $XSL_COMPILER $XSL_COMPILER_OPTIONS --param file "'$1'" --param xsl "'$2'" --param directory "'$3'" --param src "'$BASENAME'" --param xsl-compiler "'$XSL_COMPILER'" xsl/doc_script_maker.xsl $1 > $TEMP/doc_$BASENAME.sh
else
    $XSL_COMPILER -IN $1 -XSL doc_script_maker.xsl -OUT $TEMP/doc_$BASENAME.sh -PARAM file "'$1'" -PARAM xsl "'$2'" -PARAM directory "'$3'" -PARAM src "'$BASENAME'" -PARAM xsl-compiler "'$XSL_COMPILER'"
fi

exit_value || exit $EXIT

# execute  $TEMP/doc_modulename.sh
sh $TEMP/doc_$BASENAME.sh
exit_value
exit $EXIT

# don't forget to remove $TEMP/wizard.sh
#rm -f $TEMP/doc_$BASENAME.sh
